import click

from tirf_ob import version
from tirf_ob.utils.load_data import *


@click.command()
@click.option('-dir_img', '--dir_img',
              help='Directory to the image in *.tif format.',
              show_default=True)
@click.option('-dir_csv', '--dir_csv',
              help='Directory to the coordinates in *.csv format.',
              show_default=True)
@click.option('-m', '--mask_size',
              default=256,
              help='Size of the cropping mask',
              show_default=True)
@click.version_option(version=version)
def main(dir_img: str,
         dir_csv: str,
         mask_size: int):
    image = load_image_to_numpy(dir_img)
    coord = load_csv_to_numpy(dir_csv)

    # TODO interpolation
    size = image.shape
    corped_image = np.zeros((size[0], mask_size, mask_size))

    """ Main loop to corp image """
    for i in range(size[0]):
        idx = np.where(coord[:, 2] == (i + 1))[0]

        if len(idx) == 1:
            idx = idx
        elif len(idx) == 0:
            # ToDo interpolation
            assert i != 0 or i != (size[0] - 1), 'For the interpolation first and the last point are needed!'
            past = np.where(coord[:, 2] == i)[0]
            feature = np.where(coord[:, 2] == (i + 2))[0]
            idx = (coord[past, ] + coord[feature, ]) / 2
        else:
            idx = np.array(int(round(idx.mean(), 0)))

        if idx.size == 1:
            crop_y_start, crop_y_stop = coord[idx, 0] - mask_size / 2, coord[idx, 0] + mask_size / 2
            crop_x_start, crop_x_stop = coord[idx, 1] - mask_size / 2, coord[idx, 1] + mask_size / 2
        if idx.size == 3:
            crop_y_start, crop_y_stop = idx[0, 0] - mask_size / 2, idx[0, 0] + mask_size / 2
            crop_x_start, crop_x_stop = idx[0, 1] - mask_size / 2, idx[0, 1] + mask_size / 2

        corped_image[i, :, :] = image[
                                i,
                                int(crop_x_start):int(crop_x_stop),
                                int(crop_y_start): int(crop_y_stop)
                                ]

    tifffile.imsave('output.tif',
                    corped_image)


if __name__ == '__main__':
    main()



from setuptools import setup, find_packages
from tirf_ob.version import version

requirements = ['click==8.0.1',
                'numpy==1.21.0',
                'tifffile==2021.7.2'
                ]

setup(
    author="Robert Kiewisz",
    author_email='robert.kiewisz@gmail.com',
    python_requires='>=3.8',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.8',
    ],
    description="Croping tool for TIRF images",
    entry_points={
        'console_scripts': [
            'crop_tirf=tirf_ob.select_from_ROI:main',
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description_content_type='text/x-rst',
    include_package_data=True,
    keywords='tirf_ob',
    name='tirf_ob',
    packages=find_packages(include=['tirf_ob',
                                    'tirf_ob.*',
                                    'tirf_ob.utils.*']),
    version=version,
    zip_safe=False,
)



import numpy as np
from tifffile import tifffile


def load_image_to_numpy(dir: str):
    """
    Module to load 3D .tif file
    with the format [D x H x W]

    Args:
        dir:
    """

    try:
        image = tifffile.imread(dir)
    except RuntimeWarning:
        raise Warning("Directory for the file is not correct, file not found!")

    return image


def load_csv_to_numpy(dir: str):
    """
    Module to load csv files.
    Args:
         dir:
    """
    csv = np.genfromtxt(dir, delimiter=',')
    csv = csv[1:len(csv), 2:5].astype('uint16')

    return csv
